{ config, pkgs, lib, ... }:

let
  mkHost = import ../modules/host.nix {
    config = config;
    lib = lib;
    pkgs = pkgs;
  };
in mkHost {
  userName = "alexander";
  hostName = "ayame";
  wireless = true;
  overlays = [ "nur" "unstable" ];
  hardwareImports = [ "intel" "wifi" "mobile" ];
  programImports = [
    "zsh" "mpv" "git" "tmux" "firefox" "gnome-terminal" "gnome" "nonvm"
  ];
  extraImports = [ "distributed-build/offload.nix" ];
  extraPackages = pkgs: with pkgs; [
    unstable.firmwareLinuxNonFree unstable.sof-firmware
  ];
  fileSystems = {
    "/" = {
      device = "/dev/disk/by-label/root";
      fsType = "btrfs";
    };
    "/boot" = {
      device = "/dev/disk/by-label/boot";
      fsType = "vfat";
    };
  };
  swapDevices = [
    { device = "/dev/disk/by-uuid/cf3b1e1c-c245-4452-ad49-68ac72369e77"; }
  ];
  extraOptions = old: {
    boot = {
      loader = {
        systemd-boot.enable = false;
        efi.canTouchEfiVariables = false;
        grub = {
          enable = true;
          efiInstallAsRemovable = true;
          device = "nodev";
          efiSupport = true;
          # The UEFI is pretty wonky
          forcei686 = true;
        };
      };
      extraModprobeConfig = "";
      initrd = {
        availableKernelModules = [ "xhci_pci" "usbhid" "usb_storage" "sd_mod" "sdhci_acpi" ];
        kernelModules = [
          "kvm-intel" "i915"
        ];
      };
      # This spams the console and takes up so much CPU time
      kernelParams = [ "modprobe.blacklist=arizona_spi" ];
      kernelModules = [];
      extraModulePackages = [];
      kernelPackages = pkgs.linuxPackages_zen;
    };

    /*systemd.services = {
      rfkill-workaround = {
        enable = true;
        description = "Work around rfkill having the Wifi blocked at boot";
        before = [ "network.target" ];
        wantedBy = [ "multi-user.target" ];
        serviceConfig = {
          Type = "oneshot";
          ExecStart = "rfkill unblock all";
        };
      };
    };*/
  };
}
